@@ -1172,7 +1172,10 @@ bool lxApp::OnInit()
     wxFileSystem::AddHandler(new wxZipFSHandler);
     // Use a double-buffered visual if available, as it will give much smoother
     // animation.
-    int wx_gl_attribs[] = { WX_GL_RGBA, WX_GL_DOUBLEBUFFER, 0 };
+    int wx_gl_attribs[] = { 
+			WX_GL_RGBA,
+			WX_GL_DOUBLEBUFFER,
+			0 };
     if (!InitGLVisual(wx_gl_attribs)) {
 	int wx_gl_attribs_no_db[] = { WX_GL_RGBA, 0 };
 	if (!InitGLVisual(wx_gl_attribs_no_db)) {
@@ -1235,9 +1238,13 @@ void lxFrame::ExportRotationPictures() {
   this->canvas->setup->cam_orig_center = this->canvas->setup->cam_center;
   this->canvas->setup->cam_orig_pos = this->canvas->setup->cam_pos;
   for(i = 0; i < 600; i++) {
-    tmpRD->m_imgFileName = this->m_fileDir;
-	tmpRD->m_imgFileName += _T("/");
-	tmpRD->m_imgFileName += wxString::Format(_T("ROT%04d.png"), i);
+  	if (!this->m_fileDir.IsEmpty()) {
+			tmpRD->m_imgFileName = this->m_fileDir;
+			tmpRD->m_imgFileName += _T("/");
+  	} else {
+  		tmpRD->m_imgFileName = _T("");
+  	}
+    tmpRD->m_imgFileName += wxString::Format(_T("ROT%04d.png"), i);
     tmpRD->Render(this, this->canvas);
 	this->canvas->SwapBuffers();
 	if (i == 0) {
