@@ -36,6 +36,7 @@
 #include "thlocale.h"
 #include "thtmpdir.h"
 #include "thcs.h"
+#include "thproj.h"
 
 #ifdef THWIN32
 #include <windows.h>
@@ -57,7 +58,7 @@ const char * THCCC_INIT_FILE = "### Output character encodings ###\n"
 "### Paths to called executable files ###\n"
 "# mpost-path  \"mpost\"\n"
 "# mpost-options  \"-tex=etex\"\n"
-"# pdftex-path  \"pdfetex\"\n"
+"# pdftex-path  \"pdftex\"\n"
 "# cavern-path  \"cavern\"\n"
 "# convert-path  \"convert\"\n"
 "# identify-path  \"identify\"\n\n"
@@ -76,6 +77,10 @@ const char * THCCC_INIT_FILE = "### Output character encodings ###\n"
 "# tmp-path  \"\"\n\n"
 "### User defined coordinate system ###\n"
 "# cs-def <id> <proj4id> [other options]\n\n"
+"### Let PROJ v6+ find the optimal transformation ###\n"
+"# proj-auto off\n\n"
+"### PROJ v6+ handling of missing transformation grids if proj-auto is on ###\n"
+"# proj-missing-grid warn\n\n"
 "### Command to remove temporary directory ###\n"
 "# tmp-remove  \"\"\n\n";
 
@@ -114,6 +119,8 @@ enum {
   TTIC_LOOPC,
   TTIC_TEXT,	
   TTIC_PDF_FONTS,
+  TTIC_PROJ_AUTO,
+  TTIC_PROJ_MISSING_GRID,
   TTIC_OTF2PFB,
   TTIC_CS_DEF,
   TTIC_UNKNOWN,
@@ -140,6 +147,8 @@ static const thstok thtt_initcmd[] = {
   {"otf2pfb", TTIC_OTF2PFB},
   {"pdf-fonts", TTIC_PDF_FONTS},
   {"pdftex-path", TTIC_PATH_PDFTEX},
+  {"proj-auto", TTIC_PROJ_AUTO},
+  {"proj-missing-grid", TTIC_PROJ_MISSING_GRID},
   {"source-path", TTIC_PATH_SOURCE},
   {"tex-env",TTIC_TEX_ENV},
   {"tex-fonts",TTIC_TEX_FONTS},
@@ -375,12 +384,12 @@ void thinit::load()
     this->path_pdftex = thcfg.install_path.get_buffer();
     this->path_otftotfm = thcfg.install_path.get_buffer();
     this->path_mpost += "\\bin\\win32\\mpost.exe";
-    this->path_pdftex += "\\bin\\win32\\pdfetex.exe";
+    this->path_pdftex += "\\bin\\win32\\pdftex.exe";
     this->path_otftotfm += "\\bin\\win32\\otftotfm.exe";
   } else {
 #endif  
     this->path_mpost = "mpost";
-    this->path_pdftex = "pdfetex";
+    this->path_pdftex = "pdftex";
     this->path_otftotfm = "otftotfm";
 #ifdef THWIN32
   }
@@ -400,6 +409,8 @@ void thinit::load()
   }
 #endif  
 
+  set_proj_lib_path();
+
   this->tmp_path = "";
   this->tmp_remove_script = "";
   this->lang = THLANG_UNKNOWN;
@@ -439,6 +450,8 @@ void thinit::load()
         case TTIC_PATH_SOURCE:
         case TTIC_OTF2PFB:
         case TTIC_TEX_ENV:
+        case TTIC_PROJ_AUTO:
+        case TTIC_PROJ_MISSING_GRID:
           if (nargs != 2)
             ththrow(("invalid number of command arguments"));
           break;
@@ -516,6 +529,20 @@ void thinit::load()
           ENC_NEW.t1_convert = (sv == TT_TRUE);
           break;
 
+        case TTIC_PROJ_AUTO:
+          sv = thmatch_token(args[1], thtt_bool);
+          if (sv == TT_UNKNOWN_BOOL)
+            ththrow(("invalid proj-auto switch -- %s", args[1]))
+          thcs_cfg.proj_auto = (sv == TT_TRUE);
+          break;
+
+        case TTIC_PROJ_MISSING_GRID:
+          sv = thcs_parse_gridhandling(args[1]);
+          if (sv == GRID_INVALID)
+            ththrow(("invalid proj-missing-grid switch -- %s", args[1]))
+          thcs_cfg.proj_auto_grid = sv;
+          break;
+
         case TTIC_TEXT:
             thlang_set_translation(args[1], args[2], args[3]);
             break;
@@ -741,6 +768,13 @@ char * thinit::get_path_otftotfm()
 }
 
 
+void thinit::set_proj_lib_path() {  // set PROJ library resources path
+#ifdef THWIN32
+  putenv((std::string("PROJ_LIB=")+thcfg.install_path.get_buffer()+"\\lib\\proj-" + std::to_string(PROJ_VER)).c_str());
+#endif
+}
+
+
 void thprint_init_file()
 {
   thprintf(THCCC_INIT_FILE);
