@@ -26,6 +26,7 @@
  */
  
 #include "thlayout.h"
+#include "thlookup.h"
 #include "thexception.h"
 #include "thchenc.h"
 #include "thdata.h"
@@ -59,6 +60,7 @@ thlayout::thlayout()
 
   this->ccode = TT_LAYOUT_CODE_UNKNOWN;
   this->m_pconfig = NULL;
+  this->m_lookup = NULL;
 
   this->def_scale = 0;
   this->scale = 0.005;
@@ -72,6 +74,7 @@ thlayout::thlayout()
   this->ox = thnan;
   this->oy = thnan;
   this->oz = thnan;
+  this->o_cs = TTCS_LOCAL;
 
   this->def_size = 0;
   this->hsize = 0.18;
@@ -93,6 +96,8 @@ thlayout::thlayout()
   this->gox = thnan;
   this->goy = thnan;
   this->goz = thnan;
+  this->go_cs = TTCS_LOCAL;
+
   
   this->def_grid_size = 0;
   this->gxs = thnan;
@@ -241,9 +246,7 @@ thlayout::thlayout()
   this->color_preview_above.B = 0;
   
   this->color_crit = TT_LAYOUT_CCRIT_UNKNOWN;
-  this->color_mode = TT_LAYOUT_CMODE_AUTO;
-  this->color_table = TT_LAYOUT_CTABLE_HSV;  
-  
+  this->color_crit_fname = NULL;
 }
 
 
@@ -397,6 +400,8 @@ void thlayout::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
   double dum;
   thlayout_copy_src dumm;
   int sv, sv2, dum_int;
+  const char * tmp1;
+  const char * tmp2;
   //bool parsed;
   thlayout_copy_src * lcp;
   thcmd_option_desc defcod = this->get_default_cod(cod.id);
@@ -621,7 +626,8 @@ void thlayout::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
 
     case TT_LAYOUT_ORIGIN:
       //this->parse_len(this->ox, this->oy, this->oz, 3, args, -1);
-      this->convert_cs(args[0], args[1], this->ox, this->oy);
+      this->o_cs = this->cs;
+      this->read_cs(args[0], args[1], this->ox, this->oy, false);
       if (this->cs == TTCS_LOCAL) {
         this->parse_len(this->ox, this->oy, this->oz, 3, args, -1);
       } else {
@@ -668,11 +674,14 @@ void thlayout::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
           }
 	  break;
         case TT_LAYOUT_COLOR_MAP_FG:
-          this->color_crit = thmatch_token(args[1], thtt_layout_ccrit);
+          thlookup_parse_reference(args[1], &(this->color_crit), &tmp1, &tmp2);
+          //this->color_crit = thmatch_token(args[1], thtt_layout_ccrit);
           if (this->color_crit == TT_LAYOUT_CCRIT_UNKNOWN)
             this->color_map_fg.parse(args[1]);
-          else
+          else {
+            this->color_crit_fname = thdb.strstore(args[1]);
             this->color_map_fg.defined = 2;
+          }
           break;
         case TT_LAYOUT_COLOR_MAP_BG:
           this->color_map_bg.parse(args[1], true);
@@ -690,7 +699,8 @@ void thlayout::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
     
 
     case TT_LAYOUT_GRID_ORIGIN:
-      this->convert_cs(args[0], args[1], this->gox, this->goy);
+      this->go_cs = this->cs;
+      this->read_cs(args[0], args[1], this->gox, this->goy, false);
       if (this->cs == TTCS_LOCAL) {
         this->parse_len(this->gox, this->goy, this->goz, 3, args, -1);
       } else {
@@ -1099,6 +1109,8 @@ void thlayout::self_print_library() {
 
   thprintf("\tplayout->color_map_fg.defined = %d;\n", this->color_map_fg.defined);
   thprintf("\tplayout->color_crit = %d;\n", this->color_crit);
+  if (this->color_crit_fname != NULL)
+    thprintf("\tplayout->color_crit_fname = \"%s\";\n", this->color_crit_fname);
   thprintf("\tplayout->color_map_fg.R = %lg;\n",this->color_map_fg.R);
   thprintf("\tplayout->color_map_fg.G = %lg;\n",this->color_map_fg.G);
   thprintf("\tplayout->color_map_fg.B = %lg;\n",this->color_map_fg.B);
@@ -1710,7 +1722,8 @@ void thlayout::process_copy() {
         this->base_scale = srcl->base_scale;
       endcopy
 
-      begcopy(def_origin) 
+      begcopy(def_origin)
+        this->o_cs = srcl->o_cs;
         this->ox = srcl->ox;
         this->oy = srcl->oy;
         this->oz = srcl->oz;
@@ -1739,6 +1752,7 @@ void thlayout::process_copy() {
       endcopy
   
       begcopy(def_grid_origin)
+        this->go_cs = srcl->go_cs;
         this->gox = srcl->gox;
         this->goy = srcl->goy;
         this->goz = srcl->goz;
@@ -1751,6 +1765,7 @@ void thlayout::process_copy() {
       
       begcopy(color_map_fg.defined)
         this->color_crit = srcl->color_crit;
+        this->color_crit_fname = srcl->color_crit_fname;
         this->color_map_fg.R = srcl->color_map_fg.R;
         this->color_map_fg.G = srcl->color_map_fg.G;
         this->color_map_fg.B = srcl->color_map_fg.B;
@@ -2173,7 +2188,7 @@ void thlayout::export_mptex_font_size(FILE * o, th2ddataobject * obj, bool print
     case TT_2DOBJ_SCALE_XS:
       fprintf(o,"\\thtinysize ");
       break;
-    case TT_2DOBJ_SCALE_NUMBERIC:
+    case TT_2DOBJ_SCALE_NUMERIC:
     	{
     		double optical_zoom = this->scale / this->base_scale;
     		if (obj->scale_numeric <= 0.5)
@@ -2195,5 +2210,11 @@ void thlayout::export_mptex_font_size(FILE * o, th2ddataobject * obj, bool print
 
 }
 
+void thlayout::convert_all_cs() {
+	if (!thisnan(this->ox))
+		this->convert_cs(this->o_cs, this->ox, this->oy, this->ox, this->oy);
+	if (!thisnan(this->gox))
+		this->convert_cs(this->go_cs, this->gox, this->goy, this->gox, this->goy);
+}
 
 
