@@ -47,6 +47,7 @@
 //#include "thtexfonts.h"
 #include "therion.h"
 #include "thversion.h"
+#include "thconfig.h"
 #include "thlegenddata.h"
 #include "thtexfonts.h"
 
@@ -456,8 +457,12 @@ void thsvg(const char * fname, int fmt, legenddata ldata) {
   ury += LAYOUT.overlap;
 
   F << "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>" << endl;
-  
-  F << "<!-- Generated by Therion " << THVERSION << " -->" << endl;
+
+  F << "<!-- Generated by Therion";
+  if (!thcfg.reproducible_output) {
+    F << " " << THVERSION;
+  }
+  F << " -->" << endl;
   if (LAYOUT.doc_author != "") 
     F << "<!-- Author: " << LAYOUT.doc_author << " -->" << endl;
   if (LAYOUT.doc_title != "") 
